pub struct TransactionManager { /* private fields */ }Expand description
Manages pending transactions, matching responses to requests by transactionId.
Implementations
Sourceimpl TransactionManager
impl TransactionManager
pub fn new() -> Self
Sourcepub async fn create(
&self,
transaction_type: TransactionType,
) -> (String, Receiver<Result<TransactionResult, String>>)
pub async fn create( &self, transaction_type: TransactionType, ) -> (String, Receiver<Result<TransactionResult, String>>)
Create a new transaction, returning (transactionId, receiver). The receiver will get the result when the dylib responds. A timeout task is spawned that rejects after 120 seconds.
Sourcepub async fn resolve(
&self,
transaction_id: &str,
identifier: &str,
data: Option<Value>,
)
pub async fn resolve( &self, transaction_id: &str, identifier: &str, data: Option<Value>, )
Resolve a transaction with the dylib’s response.
Sourcepub async fn reject(&self, transaction_id: &str, error: &str)
pub async fn reject(&self, transaction_id: &str, error: &str)
Reject a transaction with an error message.
Sourcepub async fn is_pending(&self, transaction_id: &str) -> bool
pub async fn is_pending(&self, transaction_id: &str) -> bool
Check if a transaction ID is pending.
Sourcepub async fn pending_count(&self) -> usize
pub async fn pending_count(&self) -> usize
Number of pending transactions.